==> libreoffice_3.6.0~rc2.orig.tar.xz: libreoffice-3.6.0~rc2/drawinglayer/source/processor2d/getdigitlanguage.cxx <==
/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
/*
 * Version: MPL 1.1 / GPLv3+ / LGPLv3+
 *
 * The contents of this file are subject to the Mozilla Public License Version
 * 1.1 (the "License"); you may not use this file except in compliance with
 * the License or as specified alternatively below. You may obtain a copy of
 * the License at http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 * Major Contributor(s):
 * [ Copyright (C) 2011 Red Hat, Inc., Stephan Bergmann <sbergman@redhat.com>
 *   (initial developer) ]
 *
 * All Rights Reserved.
 *
 * For minor contributions see the git repository.
 *
 * Alternatively, the contents of this file may be used under the terms of
 * either the GNU General Public License Version 3 or later (the "GPLv3+"), or
 * the GNU Lesser General Public License Version 3 or later (the "LGPLv3+"),
 * in which case the provisions of the GPLv3+ or the LGPLv3+ are applicable
 * instead of those above.
 */

#include "sal/config.h"

#include "i18npool/lang.h"
#include "svl/ctloptions.hxx"
#include "vcl/svapp.hxx"

#include "getdigitlanguage.hxx"

LanguageType drawinglayer::detail::getDigitLanguage() {
    switch (SvtCTLOptions().GetCTLTextNumerals()) {
    case SvtCTLOptions::NUMERALS_ARABIC:
        return LANGUAGE_ENGLISH;
    case SvtCTLOptions::NUMERALS_HINDI:
        return LANGUAGE_ARABIC_SAUDI_ARABIA;
    default:
        return Application::GetSettings().GetLanguage();
    }
}

/* vim:set shiftwidth=4 softtabstop=4 expandtab: */

==> libreoffice_4.0.2.orig.tar.xz: libreoffice-4.0.2/drawinglayer/source/processor2d/getdigitlanguage.cxx <==
/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
/*
 * Version: MPL 1.1 / GPLv3+ / LGPLv3+
 *
 * The contents of this file are subject to the Mozilla Public License Version
 * 1.1 (the "License"); you may not use this file except in compliance with
 * the License or as specified alternatively below. You may obtain a copy of
 * the License at http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 * Major Contributor(s):
 * [ Copyright (C) 2011 Red Hat, Inc., Stephan Bergmann <sbergman@redhat.com>
 *   (initial developer) ]
 *
 * All Rights Reserved.
 *
 * For minor contributions see the git repository.
 *
 * Alternatively, the contents of this file may be used under the terms of
 * either the GNU General Public License Version 3 or later (the "GPLv3+"), or
 * the GNU Lesser General Public License Version 3 or later (the "LGPLv3+"),
 * in which case the provisions of the GPLv3+ or the LGPLv3+ are applicable
 * instead of those above.
 */

#include "sal/config.h"

#include "i18npool/lang.h"
#include "svl/ctloptions.hxx"
#include "vcl/svapp.hxx"

#include "getdigitlanguage.hxx"

LanguageType drawinglayer::detail::getDigitLanguage() {
    switch (SvtCTLOptions().GetCTLTextNumerals()) {
    case SvtCTLOptions::NUMERALS_ARABIC:
        return LANGUAGE_ENGLISH;
    case SvtCTLOptions::NUMERALS_HINDI:
        return LANGUAGE_ARABIC_SAUDI_ARABIA;
    default:
        return Application::GetSettings().GetLanguageTag().getLanguageType();
    }
}

/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
